@@ -21,6 +21,7 @@ utils::globalVariables(c("%>%",
                          "sample_n",
                          "scale_x_continuous",
                          "sqldf",
+                         "as.formula",
                          "time_pos",
                          "legend",
                          "points",
@@ -31,6 +32,4 @@ utils::globalVariables(c("%>%",
                          'read.table',
                          'dummy_cols',
                          "which",
-                         "pmax",
-                         "quantile",
-                         "as.formula"))
+                         "pmax"))
